@@ -79,11 +79,11 @@ pub fn parse_assoc_type(
                 }
             }
         }
-        let path = &bound.path;
+        let bounds = &assoc_type.bounds;
         return Ok((
             &assoc_type.ident,
             DestType::Box(BoxType {
-                inner: quote! {dyn #path},
+                inner: quote! {dyn #bounds},
                 placeholder_lifetime: !lifetime_bounds(&assoc_type.bounds)
                     .any(|l| l.ident == "static"),
             }),
